""" Scripts for Poetry
"""

import os
import sys

from subprocess import check_call


_project = "thermod"


def setup():
    # Setup GitHooks
    os.system("git config core.hookspath .githooks")


def database():
    # Install database
    args = sys.argv
    args.remove(args[0])
    check_call(["python", "-m", "ncm_database"] + args)


def thermod():
    # Run TherMod
    args = sys.argv
    args.remove(args[0])
    check_call(["python", "-m", _project] + args)


def example():
    # Run TherMod examples
    os.system("bash thermod/resources/example.sh")


def help():
    # Run Python help command
    check_call(["python", "-m", _project, "-h"])


def format_check():
    # Check code format
    check_call(["isort", "--check", "--diff", "."])
    check_call(["black", "--check", "--diff", "."])


def format():
    # Format code
    check_call(["isort", "."])
    check_call(["black", "."])


def lint():
    # Lint code
    check_call(["flake8", _project])


def pre_commit():
    # pre-commit Git hook
    format_check()
    # lint()


def pre_push():
    # pre-push Git hook
    pre_commit()
